[Bug regression/35671] [POSSIBLY NOT A BUG] GCC 4.3.0 vs. 4.2.3 observations
t dot artem at mailcity dot com
gcc-bugzilla@gcc.gnu.org
Mon Mar 24 23:02:00 GMT 2008
------- Comment #3 from t dot artem at mailcity dot com 2008-03-24 23:01 -------
counting all .so and .a files in lib/wine directory:
Without -ftree-vectorize:
GCC 4.2.3: 46,884,566 bytes in 305 files
GCC 4.3.0: 47,375,178 bytes in 305 files
With -ftree-vectorize:
GCC 4.2.3: 46,889,486 bytes in 305 files
GCC 4.3.0: 47,397,130 bytes in 305 files
It's not like too much to care about. I have to test using different sources.
The truth is that Windows archivers work slower in Wine compiled using GCC 4.3.
That was the real grief.
--
t dot artem at mailcity dot com changed:
What |Removed |Added
----------------------------------------------------------------------------
Status|UNCONFIRMED |RESOLVED
Resolution| |WONTFIX
http://gcc.gnu.org/bugzilla/show_bug.cgi?id=35671
More information about the Gcc-bugs
mailing list